@@ -29,10 +29,10 @@ extern "C" {
 #define MagickCopyright  "© 1999-2018 ImageMagick Studio LLC"
 #define MagickLibVersion  0x699
 #define MagickLibVersionText  "6.9.9"
-#define MagickLibVersionNumber  5,0,0
-#define MagickLibAddendum  "-40"
-#define MagickLibInterface  5
-#define MagickLibMinInterface  5
+#define MagickLibVersionNumber  6,0,0
+#define MagickLibAddendum  "-46"
+#define MagickLibInterface  6
+#define MagickLibMinInterface  6
 #if defined(_WINDOWS)
 #  if defined(_WIN64)
 #    define MagickPlatform "x64"
@@ -44,14 +44,14 @@ extern "C" {
 #endif
 #define MagickppLibVersionText  "6.9.9"
 #define MagickppLibVersionNumber  8:0:0
-#define MagickppLibAddendum  "-40"
+#define MagickppLibAddendum  "-46"
 #define MagickppLibInterface  8
 #define MagickppLibMinInterface  8
-#define MagickReleaseDate  "2018-03-25"
+#define MagickReleaseDate  "2018-05-20"
 #define MagickHomeURL  "file:///usr/share/doc/ImageMagick-6/index.html"
 #define MagickAuthoritativeLicense  \
-  "http://www.imagemagick.org/script/license.php"
-#define MagickAuthoritativeURL  "http://www.imagemagick.org"
+  "https://www.imagemagick.org/script/license.php"
+#define MagickAuthoritativeURL  "https://www.imagemagick.org"
 #if (MAGICKCORE_QUANTUM_DEPTH == 8)
 #define MagickQuantumDepth  "Q8"
 #define MagickQuantumRange  "255"
